#!/bin/bash

set -e

# get the root of the git repository (requires git to be installed)
GIT_ROOT=`git rev-parse --show-toplevel`
cd $GIT_ROOT

# define useful variables
source generation/00env.sh

metadata_file=metadata.json
sha_list=installation/images-sha512.list
hash_comment="# self-compiled kernel, network autoconfig off + dummy ips, rd.neednet=1 LABEL=Root, metadata in shadir, no scan no send"

version_to_list () {
	# take a version with no letters, and return a json list
	# remove everything after "+" and "-", and separate numbers according to "."
	python3 -c "import sys; print(list(map(int, sys.argv[1].split(\"+\")[0].split(\"-\")[0].split(\".\"))))" "$1"
}
kernel_revision_arch=$(uname -r)

# strings have to be quoted so that the file is decoded as valid json
json_metadata="{ \
	\"server-group\": \"$SERVER_GROUP\", \
	\"kernel-version\": $(version_to_list $(uname -v | cut -d' ' -f4)), \
	\"kernel-revision\": \"${kernel_revision_arch%-*}\", \
	\"mca-version\": $(version_to_list $MCA_VERSION), \
	\"flb-version\": $(version_to_list $FLB_VERSION), \
	\"plg-version\": $(version_to_list $PLG_VERSION), \
	\"timestamp\": $(date +%s), \
	\"comment\": \"$hash_comment\" \
}"
echo "$json_metadata" > "$metadata_file"
networkcache-upload --conf ../tls-access-to-shacache/test.cfg --key river --file "$UEFI_IMAGE_NAME" --metadata "$metadata_file"

echo $(sha512sum "$UEFI_IMAGE_NAME" | cut -d' ' -f1) "$hash_comment" >> "$sha_list"
echo "$UEFI_IMAGE_NAME"
git add "$sha_list"
git commit -m "installation: Add an image hash."
git push
